chemcoord.AsymmetricUnitCartesian
=================================

.. currentmodule:: chemcoord

.. autoclass:: AsymmetricUnitCartesian

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AsymmetricUnitCartesian.__init__
      ~AsymmetricUnitCartesian.add_data
      ~AsymmetricUnitCartesian.align
      ~AsymmetricUnitCartesian.apply
      ~AsymmetricUnitCartesian.applymap
      ~AsymmetricUnitCartesian.basistransform
      ~AsymmetricUnitCartesian.change_numbering
      ~AsymmetricUnitCartesian.check_absolute_refs
      ~AsymmetricUnitCartesian.check_dihedral
      ~AsymmetricUnitCartesian.copy
      ~AsymmetricUnitCartesian.correct_absolute_refs
      ~AsymmetricUnitCartesian.correct_dihedral
      ~AsymmetricUnitCartesian.cut_cuboid
      ~AsymmetricUnitCartesian.cut_sphere
      ~AsymmetricUnitCartesian.fragmentate
      ~AsymmetricUnitCartesian.from_ase_atoms
      ~AsymmetricUnitCartesian.from_pymatgen_molecule
      ~AsymmetricUnitCartesian.get_align_transf
      ~AsymmetricUnitCartesian.get_angle_degrees
      ~AsymmetricUnitCartesian.get_ase_atoms
      ~AsymmetricUnitCartesian.get_asymmetric_unit
      ~AsymmetricUnitCartesian.get_barycenter
      ~AsymmetricUnitCartesian.get_bond_lengths
      ~AsymmetricUnitCartesian.get_bonds
      ~AsymmetricUnitCartesian.get_cartesian
      ~AsymmetricUnitCartesian.get_centroid
      ~AsymmetricUnitCartesian.get_construction_table
      ~AsymmetricUnitCartesian.get_coordination_sphere
      ~AsymmetricUnitCartesian.get_dihedral_degrees
      ~AsymmetricUnitCartesian.get_distance_to
      ~AsymmetricUnitCartesian.get_electron_number
      ~AsymmetricUnitCartesian.get_equivalent_atoms
      ~AsymmetricUnitCartesian.get_fragment
      ~AsymmetricUnitCartesian.get_grad_zmat
      ~AsymmetricUnitCartesian.get_inertia
      ~AsymmetricUnitCartesian.get_pointgroup
      ~AsymmetricUnitCartesian.get_pymatgen_molecule
      ~AsymmetricUnitCartesian.get_shortest_distance
      ~AsymmetricUnitCartesian.get_total_mass
      ~AsymmetricUnitCartesian.get_without
      ~AsymmetricUnitCartesian.get_zmat
      ~AsymmetricUnitCartesian.has_same_sumformula
      ~AsymmetricUnitCartesian.insert
      ~AsymmetricUnitCartesian.partition_chem_env
      ~AsymmetricUnitCartesian.read_cjson
      ~AsymmetricUnitCartesian.read_xyz
      ~AsymmetricUnitCartesian.reindex_similar
      ~AsymmetricUnitCartesian.replace
      ~AsymmetricUnitCartesian.reset_index
      ~AsymmetricUnitCartesian.restrict_bond_dict
      ~AsymmetricUnitCartesian.set_index
      ~AsymmetricUnitCartesian.sort_index
      ~AsymmetricUnitCartesian.sort_values
      ~AsymmetricUnitCartesian.subs
      ~AsymmetricUnitCartesian.symmetrize
      ~AsymmetricUnitCartesian.to_cjson
      ~AsymmetricUnitCartesian.to_latex
      ~AsymmetricUnitCartesian.to_string
      ~AsymmetricUnitCartesian.to_xyz
      ~AsymmetricUnitCartesian.to_zmat
      ~AsymmetricUnitCartesian.view
      ~AsymmetricUnitCartesian.write_xyz
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AsymmetricUnitCartesian.columns
      ~AsymmetricUnitCartesian.dtypes
      ~AsymmetricUnitCartesian.empty
      ~AsymmetricUnitCartesian.iloc
      ~AsymmetricUnitCartesian.index
      ~AsymmetricUnitCartesian.loc
      ~AsymmetricUnitCartesian.shape
   
   